@@ -357,6 +357,132 @@ class DescribeSeatUserListResponse(AbstractModel):
         self.RequestId = params.get("RequestId")
 
 
+class DescribeSkillGroupInfoListRequest(AbstractModel):
+    """DescribeSkillGroupInfoList请求参数结构体
+
+    """
+
+    def __init__(self):
+        """
+        :param SdkAppId: 应用ID
+        :type SdkAppId: int
+        :param PageSize: 分页尺寸，上限 100
+        :type PageSize: int
+        :param PageNumber: 分页页码，从 0 开始
+        :type PageNumber: int
+        :param SkillGroupId: 技能组ID，查询单个技能组时使用
+        :type SkillGroupId: int
+        :param ModifiedTime: 查询修改时间大于等于ModifiedTime的技能组时使用
+        :type ModifiedTime: int
+        """
+        self.SdkAppId = None
+        self.PageSize = None
+        self.PageNumber = None
+        self.SkillGroupId = None
+        self.ModifiedTime = None
+
+
+    def _deserialize(self, params):
+        self.SdkAppId = params.get("SdkAppId")
+        self.PageSize = params.get("PageSize")
+        self.PageNumber = params.get("PageNumber")
+        self.SkillGroupId = params.get("SkillGroupId")
+        self.ModifiedTime = params.get("ModifiedTime")
+
+
+class DescribeSkillGroupInfoListResponse(AbstractModel):
+    """DescribeSkillGroupInfoList返回参数结构体
+
+    """
+
+    def __init__(self):
+        """
+        :param TotalCount: 技能组总数
+        :type TotalCount: int
+        :param SkillGroupList: 技能组信息列表
+        :type SkillGroupList: list of SkillGroupInfoItem
+        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :type RequestId: str
+        """
+        self.TotalCount = None
+        self.SkillGroupList = None
+        self.RequestId = None
+
+
+    def _deserialize(self, params):
+        self.TotalCount = params.get("TotalCount")
+        if params.get("SkillGroupList") is not None:
+            self.SkillGroupList = []
+            for item in params.get("SkillGroupList"):
+                obj = SkillGroupInfoItem()
+                obj._deserialize(item)
+                self.SkillGroupList.append(obj)
+        self.RequestId = params.get("RequestId")
+
+
+class DescribeStaffInfoListRequest(AbstractModel):
+    """DescribeStaffInfoList请求参数结构体
+
+    """
+
+    def __init__(self):
+        """
+        :param SdkAppId: 应用ID
+        :type SdkAppId: int
+        :param PageSize: 分页尺寸，上限 100
+        :type PageSize: int
+        :param PageNumber: 分页页码，从 0 开始
+        :type PageNumber: int
+        :param StaffMail: 坐席账号，查询单个坐席时使用
+        :type StaffMail: str
+        :param ModifiedTime: 查询修改时间大于等于ModifiedTime的坐席时使用
+        :type ModifiedTime: int
+        """
+        self.SdkAppId = None
+        self.PageSize = None
+        self.PageNumber = None
+        self.StaffMail = None
+        self.ModifiedTime = None
+
+
+    def _deserialize(self, params):
+        self.SdkAppId = params.get("SdkAppId")
+        self.PageSize = params.get("PageSize")
+        self.PageNumber = params.get("PageNumber")
+        self.StaffMail = params.get("StaffMail")
+        self.ModifiedTime = params.get("ModifiedTime")
+
+
+class DescribeStaffInfoListResponse(AbstractModel):
+    """DescribeStaffInfoList返回参数结构体
+
+    """
+
+    def __init__(self):
+        """
+        :param TotalCount: 坐席用户总数
+        :type TotalCount: int
+        :param StaffList: 坐席用户信息列表
+        :type StaffList: list of StaffInfo
+        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :type RequestId: str
+        """
+        self.TotalCount = None
+        self.StaffList = None
+        self.RequestId = None
+
+
+    def _deserialize(self, params):
+        self.TotalCount = params.get("TotalCount")
+        if params.get("StaffList") is not None:
+            self.StaffList = []
+            for item in params.get("StaffList"):
+                obj = StaffInfo()
+                obj._deserialize(item)
+                self.StaffList.append(obj)
+        self.RequestId = params.get("RequestId")
+
+
 class DescribeTelCallInfoRequest(AbstractModel):
     """DescribeTelCallInfo请求参数结构体
 
@@ -794,6 +920,132 @@ class ServeParticipant(AbstractModel):
         self.SkillGroupName = params.get("SkillGroupName")
 
 
+class SkillGroupInfoItem(AbstractModel):
+    """技能组信息
+
+    """
+
+    def __init__(self):
+        """
+        :param SkillGroupId: 技能组ID
+        :type SkillGroupId: int
+        :param SkillGroupName: 技能组名称
+        :type SkillGroupName: str
+        :param Type: 类型：IM、TEL、ALL（全媒体）
+        :type Type: str
+        :param RoutePolicy: 会话分配策略
+注意：此字段可能返回 null，表示取不到有效值。
+        :type RoutePolicy: str
+        :param UsingLastSeat: 会话分配是否优先上次服务坐席
+注意：此字段可能返回 null，表示取不到有效值。
+        :type UsingLastSeat: int
+        :param MaxConcurrency: 单客服最大并发数（电话类型默认1）
+注意：此字段可能返回 null，表示取不到有效值。
+        :type MaxConcurrency: int
+        :param LastModifyTimestamp: 最后修改时间
+注意：此字段可能返回 null，表示取不到有效值。
+        :type LastModifyTimestamp: int
+        """
+        self.SkillGroupId = None
+        self.SkillGroupName = None
+        self.Type = None
+        self.RoutePolicy = None
+        self.UsingLastSeat = None
+        self.MaxConcurrency = None
+        self.LastModifyTimestamp = None
+
+
+    def _deserialize(self, params):
+        self.SkillGroupId = params.get("SkillGroupId")
+        self.SkillGroupName = params.get("SkillGroupName")
+        self.Type = params.get("Type")
+        self.RoutePolicy = params.get("RoutePolicy")
+        self.UsingLastSeat = params.get("UsingLastSeat")
+        self.MaxConcurrency = params.get("MaxConcurrency")
+        self.LastModifyTimestamp = params.get("LastModifyTimestamp")
+
+
+class SkillGroupItem(AbstractModel):
+    """技能组信息
+
+    """
+
+    def __init__(self):
+        """
+        :param SkillGroupId: 技能组ID
+        :type SkillGroupId: int
+        :param SkillGroupName: 技能组名称
+        :type SkillGroupName: str
+        :param Priority: 优先级
+        :type Priority: int
+        :param Type: 类型：IM、TEL、ALL（全媒体）
+        :type Type: str
+        """
+        self.SkillGroupId = None
+        self.SkillGroupName = None
+        self.Priority = None
+        self.Type = None
+
+
+    def _deserialize(self, params):
+        self.SkillGroupId = params.get("SkillGroupId")
+        self.SkillGroupName = params.get("SkillGroupName")
+        self.Priority = params.get("Priority")
+        self.Type = params.get("Type")
+
+
+class StaffInfo(AbstractModel):
+    """带有技能组优先级的坐席信息
+
+    """
+
+    def __init__(self):
+        """
+        :param Name: 坐席名称
+注意：此字段可能返回 null，表示取不到有效值。
+        :type Name: str
+        :param Mail: 坐席邮箱
+        :type Mail: str
+        :param Phone: 坐席电话号码
+注意：此字段可能返回 null，表示取不到有效值。
+        :type Phone: str
+        :param Nick: 坐席昵称
+注意：此字段可能返回 null，表示取不到有效值。
+        :type Nick: str
+        :param StaffNumber: 坐席工号
+注意：此字段可能返回 null，表示取不到有效值。
+        :type StaffNumber: str
+        :param SkillGroupList: 所属技能组列表
+注意：此字段可能返回 null，表示取不到有效值。
+        :type SkillGroupList: list of SkillGroupItem
+        :param LastModifyTimestamp: 最后修改时间
+注意：此字段可能返回 null，表示取不到有效值。
+        :type LastModifyTimestamp: int
+        """
+        self.Name = None
+        self.Mail = None
+        self.Phone = None
+        self.Nick = None
+        self.StaffNumber = None
+        self.SkillGroupList = None
+        self.LastModifyTimestamp = None
+
+
+    def _deserialize(self, params):
+        self.Name = params.get("Name")
+        self.Mail = params.get("Mail")
+        self.Phone = params.get("Phone")
+        self.Nick = params.get("Nick")
+        self.StaffNumber = params.get("StaffNumber")
+        if params.get("SkillGroupList") is not None:
+            self.SkillGroupList = []
+            for item in params.get("SkillGroupList"):
+                obj = SkillGroupItem()
+                obj._deserialize(item)
+                self.SkillGroupList.append(obj)
+        self.LastModifyTimestamp = params.get("LastModifyTimestamp")
+
+
 class TelCdrInfo(AbstractModel):
     """电话话单信息
 
@@ -815,7 +1067,29 @@ class TelCdrInfo(AbstractModel):
         :type RecordURL: str
         :param SeatUser: 坐席信息
         :type SeatUser: :class:`tencentcloud.ccc.v20200210.models.SeatUserInfo`
-        :param EndStatus: 结束状态 0 未知 1 正常通话 2 未接通
+        :param EndStatus: 结束状态
+0	错误
+1	正常结束
+2	未接通
+17	坐席未接
+100	黑名单
+101	坐席转接
+102	IVR 期间用户放弃
+103	会话排队期间用户放弃
+104	会话振铃期间用户放弃
+105	无坐席在线
+106	非工作时间
+107	IVR后直接结束
+201	未知状态
+202	未接听
+203	拒接挂断
+204	关机
+205	空号
+206	通话中
+207	欠费
+208	运营商线路异常
+209	主叫取消
+210	不在服务区
         :type EndStatus: int
         :param SkillGroup: 技能组名称
         :type SkillGroup: str
@@ -845,14 +1119,28 @@ class TelCdrInfo(AbstractModel):
         :param SkillGroupId: 技能组ID
 注意：此字段可能返回 null，表示取不到有效值。
         :type SkillGroupId: int
-        :param EndStatusString: ok 正常结束 
-unconnected	未接通
-seatGiveUp	坐席未接
-seatForward	坐席转接
-ivrGiveUp	IVR期间用户放弃
-waitingGiveUp	会话排队期间用户放弃
-ringingGiveUp	会话振铃期间用户放弃
-error	系统错误
+        :param EndStatusString: error                   错误
+ok                       正常结束
+unconnected      未接通
+seatGiveUp         坐席未接
+blackList             黑名单
+seatForward       坐席转接
+ivrGiveUp           IVR 期间用户放弃
+waitingGiveUp   会话排队期间用户放弃
+ringingGiveUp   会话振铃期间用户放弃
+noSeatOnline     无坐席在线
+notWorkTime     非工作时间
+ivrEnd                 IVR后直接结束
+unknown            未知状态
+notAnswer          未接听
+userReject          拒接挂断
+powerOff            关机
+numberNotExist  空号
+busy                    通话中
+outOfCredit        欠费
+operatorError     运营商线路异常
+callerCancel        主叫取消
+notInService       不在服务区
 注意：此字段可能返回 null，表示取不到有效值。
         :type EndStatusString: str
         :param StartTimestamp: 会话开始时间戳，UNIX 秒级时间戳
@@ -867,6 +1155,9 @@ error	系统错误
         :param QueuedSkillGroupId: 排队技能组Id
 注意：此字段可能返回 null，表示取不到有效值。
         :type QueuedSkillGroupId: int
+        :param SessionId: 会话 ID
+注意：此字段可能返回 null，表示取不到有效值。
+        :type SessionId: str
         """
         self.Caller = None
         self.Callee = None
@@ -891,6 +1182,7 @@ error	系统错误
         self.QueuedTimestamp = None
         self.PostIVRKeyPressed = None
         self.QueuedSkillGroupId = None
+        self.SessionId = None
 
 
     def _deserialize(self, params):
@@ -928,4 +1220,5 @@ error	系统错误
                 obj = IVRKeyPressedElement()
                 obj._deserialize(item)
                 self.PostIVRKeyPressed.append(obj)
-        self.QueuedSkillGroupId = params.get("QueuedSkillGroupId")
\ No newline at end of file
+        self.QueuedSkillGroupId = params.get("QueuedSkillGroupId")
+        self.SessionId = params.get("SessionId")
\ No newline at end of file
